@@ -4,9 +4,9 @@ libtmux.window
 ~~~~~~~~~~~~~~
 
 """
+
 import dataclasses
 import logging
-import pathlib
 import shlex
 import typing as t
 import warnings
@@ -15,14 +15,15 @@ from libtmux._internal.query_list import QueryList
 from libtmux.common import has_gte_version, tmux_cmd
 from libtmux.constants import (
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    PaneDirection,
     ResizeAdjustmentDirection,
+    WindowDirection,
 )
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
 
 from . import exc
-from .common import PaneDict, WindowOptionDict, handle_option_error, has_lt_version
-from .formats import FORMAT_SEPARATOR
+from .common import PaneDict, WindowOptionDict, handle_option_error
 
 if t.TYPE_CHECKING:
     from .server import Server
@@ -53,7 +54,7 @@ class Window(Obj):
     >>> window.panes
     [Pane(...)]
 
-    >>> window.attached_pane
+    >>> window.active_pane
     Pane(...)
 
     Relations moving up:
@@ -61,10 +62,10 @@ class Window(Obj):
     >>> window.session
     Session(...)
 
-    >>> window.window_id == session.attached_window.window_id
+    >>> window.window_id == session.active_window.window_id
     True
 
-    >>> window == session.attached_window
+    >>> window == session.active_window
     True
 
     >>> window in session.windows
@@ -136,18 +137,43 @@ class Window(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Execute tmux subcommand against target window. See :meth:`Server.cmd`.
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+        target: t.Optional[t.Union[str, int]] = None,
+    ) -> tmux_cmd:
+        """Execute tmux subcommand within window context.
 
-        Send command to tmux with :attr:`window_id` as ``target-window``.
+        Automatically binds target by adding  ``-t`` for object's window ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
-        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
-        ``args`` will override using the object's ``window_id`` as target.
+        Examples
+        --------
+        Create a pane from a window:
+
+        >>> window.cmd('split-window', '-P', '-F#{pane_id}').stdout[0]
+        '%...'
+
+        Magic, directly to a `Pane`:
+
+        >>> Pane.from_pane_id(pane_id=session.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=session.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the window ID.
+
+        Returns
+        -------
+        :meth:`server.cmd`
         """
-        if not any("-t" in str(x) for x in args):
-            args = ("-t", self.window_id, *args)
+        if target is None:
+            target = self.window_id
 
-        return self.server.cmd(cmd, *args, **kwargs)
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
@@ -167,30 +193,30 @@ class Window(Obj):
         -------
         :class:`Pane`
         """
-        if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
-            proc = self.cmd("select-pane", "-t%s" % self.window_id, target_pane)
+        if target_pane in {"-l", "-U", "-D", "-L", "-R"}:
+            proc = self.cmd("select-pane", target_pane)
         else:
-            proc = self.cmd("select-pane", "-t%s" % target_pane)
+            proc = self.cmd("select-pane", target=target_pane)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return self.attached_pane
+        return self.active_pane
 
-    def split_window(
+    def split(
         self,
+        /,
         target: t.Optional[t.Union[int, str]] = None,
         start_directory: t.Optional[str] = None,
         attach: bool = False,
-        vertical: bool = True,
+        direction: t.Optional[PaneDirection] = None,
+        full_window_split: t.Optional[bool] = None,
+        zoom: t.Optional[bool] = None,
         shell: t.Optional[str] = None,
         size: t.Optional[t.Union[str, int]] = None,
-        percent: t.Optional[int] = None,  # deprecated
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Pane":
-        """Split window and return the created :class:`Pane`.
-
-        Used for splitting window and holding in a python object.
+        """Split window on active pane and return the created :class:`Pane`.
 
         Parameters
         ----------
@@ -199,10 +225,12 @@ class Window(Obj):
             True.
         start_directory : str, optional
             specifies the working directory in which the new window is created.
-        target : str
-            ``target_pane`` to split.
-        vertical : str
-            split vertically
+        direction : PaneDirection, optional
+            split in direction. If none is specified, assume down.
+        full_window_split: bool, optional
+            split across full window width or height, rather than active pane.
+        zoom: bool, optional
+            expand pane
         shell : str, optional
             execute a command on splitting the window.  The pane will close
             when the command exits.
@@ -212,111 +240,25 @@ class Window(Obj):
             window upon completion is desired.
         size: int, optional
             Cell/row or percentage to occupy with respect to current window.
-        percent: int, optional
-            Deprecated in favor of size. Percentage to occupy with respect to current
-            window.
         environment: dict, optional
             Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
-
-        Notes
-        -----
-        :term:`tmux(1)` will move window to the new pane if the
-        ``split-window`` target is off screen. tmux handles the ``-d`` the
-        same way as ``new-window`` and ``attach`` in
-        :class:`Session.new_window`.
-
-        By default, this will make the window the pane is created in
-        active. To remain on the same window and split the pane in another
-        target window, pass in ``attach=False``.
-
-        .. versionchanged:: 0.28.0
-
-           ``attach`` default changed from ``True`` to ``False``.
-
-        .. deprecated:: 0.28.0
-
-           ``percent=25`` deprecated in favor of ``size="25%"``.
         """
-        tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
-
-        tmux_args: t.Tuple[str, ...] = ()
-
-        if target is not None:
-            tmux_args += ("-t%s" % target,)
-        else:
-            if len(self.panes):
-                tmux_args += (
-                    f"-t{self.session_id}:{self.window_id}.{self.panes[0].pane_index}",
-                )
-            else:
-                tmux_args += (f"-t{self.session_id}:{self.window_id}",)
-
-        if vertical:
-            tmux_args += ("-v",)
-        else:
-            tmux_args += ("-h",)
-
-        if size is not None:
-            if has_lt_version("3.1"):
-                if isinstance(size, str) and size.endswith("%"):
-                    tmux_args += (f'-p{str(size).rstrip("%")}',)
-                else:
-                    warnings.warn(
-                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
-                        stacklevel=2,
-                    )
-            else:
-                tmux_args += (f"-l{size}",)
-
-        if percent is not None:
-            # Deprecated in 3.1 in favor of -l
-            warnings.warn(
-                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
-                + ' ("-l" flag) in tmux 3.1+.',
-                category=DeprecationWarning,
-                stacklevel=2,
-            )
-            tmux_args += (f"-p{percent}",)
-
-        tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
-
-        if start_directory is not None:
-            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
-            start_path = pathlib.Path(start_directory).expanduser()
-            tmux_args += (f"-c{start_path}",)
-
-        if not attach:
-            tmux_args += ("-d",)
-
-        if environment:
-            if has_gte_version("3.0"):
-                for k, v in environment.items():
-                    tmux_args += (f"-e{k}={v}",)
-            else:
-                logger.warning(
-                    "Environment flag ignored, tmux 3.0 or newer required.",
-                )
-
-        if shell:
-            tmux_args += (shell,)
-
-        pane_cmd = self.cmd("split-window", *tmux_args)
-
-        # tmux < 1.7. This is added in 1.7.
-        if pane_cmd.stderr:
-            if "pane too small" in pane_cmd.stderr:
-                raise exc.LibTmuxException(pane_cmd.stderr)
-
-            raise exc.LibTmuxException(pane_cmd.stderr, self.__dict__, self.panes)
-
-        pane_output = pane_cmd.stdout[0]
-
-        pane_formatters = dict(zip(["pane_id"], pane_output.split(FORMAT_SEPARATOR)))
-
-        return Pane.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
+        active_pane = self.active_pane or self.panes[0]
+        return active_pane.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=direction,
+            full_window_split=full_window_split,
+            zoom=zoom,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
 
     def resize(
         self,
+        /,
         # Adjustments
         adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
         adjustment: t.Optional[int] = None,
@@ -368,16 +310,16 @@ class Window(Obj):
 
         tmux_args: t.Tuple[str, ...] = ()
 
-        ## Adjustments
+        # Adjustments
         if adjustment_direction:
             if adjustment is None:
-                raise exc.WindowAdjustmentDirectionRequiresAdjustment()
+                raise exc.WindowAdjustmentDirectionRequiresAdjustment
             tmux_args += (
                 f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
                 str(adjustment),
             )
         elif height or width:
-            ## Manual resizing
+            # Manual resizing
             if height:
                 tmux_args += (f"-y{int(height)}",)
             if width:
@@ -431,7 +373,7 @@ class Window(Obj):
             'custom'
                 custom dimensions (see :term:`tmux(1)` manpages).
         """
-        cmd = ["select-layout", f"-t{self.session_id}:{self.window_index}"]
+        cmd = ["select-layout"]
 
         if layout:  # tmux allows select-layout without args
             cmd.append(layout)
@@ -468,7 +410,6 @@ class Window(Obj):
 
         cmd = self.cmd(
             "set-window-option",
-            f"-t{self.session_id}:{self.window_index}",
             option,
             value,
         )
@@ -573,7 +514,7 @@ class Window(Obj):
 
         Examples
         --------
-        >>> window = session.attached_window
+        >>> window = session.active_window
 
         >>> window.rename_window('My project')
         Window(@1 1:My project, Session($1 ...))
@@ -650,8 +591,6 @@ class Window(Obj):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return None
-
     def move_window(
         self,
         destination: str = "",
@@ -672,7 +611,7 @@ class Window(Obj):
         proc = self.cmd(
             "move-window",
             f"-s{self.session_id}:{self.window_index}",
-            f"-t{session}:{destination}",
+            target=f"{session}:{destination}",
         )
 
         if proc.stderr:
@@ -685,6 +624,66 @@ class Window(Obj):
 
         return self
 
+    def new_window(
+        self,
+        window_name: t.Optional[str] = None,
+        *,
+        start_directory: None = None,
+        attach: bool = False,
+        window_index: str = "",
+        window_shell: t.Optional[str] = None,
+        environment: t.Optional[t.Dict[str, str]] = None,
+        direction: t.Optional[WindowDirection] = None,
+    ) -> "Window":
+        """Create new window respective of current window's position.
+
+        See Also
+        --------
+        :meth:`Session.new_window()`
+
+        Examples
+        --------
+        .. ::
+            >>> import pytest
+            >>> from libtmux.common import has_lt_version
+            >>> if has_lt_version('3.2'):
+            ...     pytest.skip('This doctest requires tmux 3.2 or newer')
+        >>> window_initial = session.new_window(window_name='Example')
+        >>> window_initial
+        Window(@... 2:Example, Session($1 libtmux_...))
+        >>> window_initial.window_index
+        '2'
+
+        >>> window_before = window_initial.new_window(
+        ... window_name='Window before', direction=WindowDirection.Before)
+        >>> window_initial.refresh()
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+
+        >>> window_after = window_initial.new_window(
+        ... window_name='Window after', direction=WindowDirection.After)
+        >>> window_initial.refresh()
+        >>> window_after.refresh()
+        >>> window_after
+        Window(@... 4:Window after, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        """
+        return self.session.new_window(
+            window_name=window_name,
+            start_directory=start_directory,
+            attach=attach,
+            window_index=window_index,
+            window_shell=window_shell,
+            environment=environment,
+            direction=direction,
+            target_window=self.window_id,
+        )
+
     #
     # Climbers
     #
@@ -697,7 +696,7 @@ class Window(Obj):
 
         Examples
         --------
-        >>> window = session.attached_window
+        >>> window = session.active_window
         >>> new_window = session.new_window()
         >>> session.refresh()
         >>> active_windows = [w for w in session.windows if w.window_active == '1']
@@ -724,11 +723,11 @@ class Window(Obj):
     # Computed properties
     #
     @property
-    def attached_pane(self) -> t.Optional["Pane"]:
+    def active_pane(self) -> t.Optional["Pane"]:
         """Return attached :class:`Pane`."""
-        for pane in self.panes:
-            if pane.pane_active == "1":
-                return pane
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
         return None
 
     #
@@ -742,12 +741,9 @@ class Window(Obj):
 
     def __repr__(self) -> str:
         """Representation of :class:`Window` object."""
-        return "{}({} {}:{}, {})".format(
-            self.__class__.__name__,
-            self.window_id,
-            self.window_index,
-            self.window_name,
-            self.session,
+        return (
+            f"{self.__class__.__name__}({self.window_id} "
+            + f"{self.window_index}:{self.window_name}, {self.session})"
         )
 
     #
@@ -816,6 +812,80 @@ class Window(Obj):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    def split_window(
+        self,
+        target: t.Optional[t.Union[int, str]] = None,
+        start_directory: t.Optional[str] = None,
+        attach: bool = False,
+        vertical: bool = True,
+        shell: t.Optional[str] = None,
+        size: t.Optional[t.Union[str, int]] = None,
+        percent: t.Optional[int] = None,  # deprecated
+        environment: t.Optional[t.Dict[str, str]] = None,
+    ) -> "Pane":
+        """Split window and return the created :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.33.0
+
+           Deprecated in favor of :meth:`.split()`.
+
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
+        .. deprecated:: 0.28.0
+
+           ``percent=25`` deprecated in favor of ``size="25%"``.
+        """
+        warnings.warn(
+            "Window.split_window() is deprecated in favor of Window.split()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+
+        if percent is not None:
+            # Deprecated in 3.1 in favor of -l
+            warnings.warn(
+                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
+                + ' ("-l" flag) in tmux 3.1+.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+            if size is None:
+                size = f"{str(percent).rstrip('%')}%"
+
+        return self.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=PaneDirection.Below if vertical else PaneDirection.Right,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
+    @property
+    def attached_pane(self) -> t.Optional["Pane"]:
+        """Return attached :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.31
+
+           Deprecated in favor of :meth:`.active_pane`.
+        """
+        warnings.warn(
+            "Window.attached_pane() is deprecated in favor of Window.active_pane()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
+        return None
+
     def select_window(self) -> "Window":
         """Select window.
 
@@ -847,10 +917,7 @@ class Window(Obj):
             category=DeprecationWarning,
             stacklevel=2,
         )
-        proc = self.cmd(
-            "kill-window",
-            f"-t{self.session_id}:{self.window_index}",
-        )
+        proc = self.cmd("kill-window")
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -865,7 +932,9 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Window.get() is deprecated", category=DeprecationWarning, stacklevel=2
+            "Window.get() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return getattr(self, key, default)
 
@@ -909,7 +978,9 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Window.where() is deprecated", category=DeprecationWarning, stacklevel=2
+            "Window.where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         try:
             return self.panes.filter(**kwargs)
@@ -967,7 +1038,9 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "list_panes() is deprecated", category=DeprecationWarning, stacklevel=2
+            "list_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self.panes
 
@@ -981,6 +1054,8 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+            "Server.children is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self.panes
